%
% File: monty_hall.m
% Project: Probability and Statistics
% Description: Monty Hall problem simulation
% Date: January 2015
% Author: Faton M. Berisha
% Version: 1.0
%
%	Suppose you're on a game show,
%	and you're given the choice of three doors:                                           
%	Behind one door is a car;
%	behind the others, goats.
%	You pick a door, say No. 1, and the host,
%	who knows what's behind the doors, opens another door, say No. 3,
%	which has a goat.
%	He then says to you, "Do you want to pick door No. 2?"
%	Is it to your advantage to switch your choice?
%
%	Standard assumptions:
%   1. The host must always open a door that was not picked by the contestant.
%   2. The host must always open a door to reveal a goat and never the car.
%   3. The host must always offer the chance to switch
%		between the originally chosen door and the remaining closed door.

X = [
	0, 1;
	0, 0
];

trials = 1e7;

rnd = rand(trials, 1);
i_car = floor(3 * rnd) + 1;

rnd = rand(trials, 1);
i_choice = floor(3 * rnd) + 1;

found = i_choice == i_car;
rnd = rand(trials, 1);
tmp = floor(2 * rnd) + 1;
i_goat = found .* (mod(i_choice - 1 + tmp, 3) + 1) ...
	+ (1 - found) .* (6 - (i_car + i_choice));

i_switch = 6 - (i_choice + i_goat);

sample = [i_choice == i_car, i_switch == i_car];

X(2, :) = sum(sample);

X

p = X(2, :) / sum(X(2, :))

